//
//  APIService.swift
//  untitled
//
//  Created by Raj Sharma on 04/03/24.
//

import Foundation

class APIService: NSObject {
    lazy var urlSession: URLSession = {
        let configuration = URLSessionConfiguration.default
        configuration.urlCache = nil // Disable caching for this session
        configuration.requestCachePolicy = .reloadIgnoringLocalCacheData // Ignore local cache
        return URLSession(configuration: configuration, delegate: self, delegateQueue: nil)
    }()
    
    func fetchData() async throws -> ResponseModel {
        let url = URL(string: Constants.apiEndpoint)!
        let (data, _) = try await urlSession.data(from: url)
        let responseModel = try JSONDecoder().decode(ResponseModel.self, from: data)
        return responseModel
    }
}

extension APIService: URLSessionDelegate {
    func urlSession(_ session: URLSession, didReceive challenge: URLAuthenticationChallenge, completionHandler: @escaping (URLSession.AuthChallengeDisposition, URLCredential?) -> Void) {
        // WARNING: Using .useCredential without validating the certificate poses a security risk
        if challenge.protectionSpace.authenticationMethod == NSURLAuthenticationMethodServerTrust,
           let serverTrust = challenge.protectionSpace.serverTrust {
            let credential = URLCredential(trust: serverTrust)
            completionHandler(.useCredential, credential)
        } else {
            completionHandler(.performDefaultHandling, nil)
        }
    }
}

