//
//  ContentViewModel.swift
//  untitled
//
//  Created by Raj Sharma on 04/03/24.
//

import SwiftUI

class ContentViewModel: ObservableObject {
    @Published var responseString: String?
    @Published var translatedText: String?
    @Published var isLoading = false
    @Published var error: Error?
    
    private var apiService = APIService()
    private var translationService = TranslationService()
    
    func fetchData() async {
        isLoading = true
        do {
            let responseModel = try await apiService.fetchData()
            responseString = responseModel.ha_response
            isLoading = false
        } catch {
            self.error = error
            isLoading = false
        }
    }
    
    func updateUIWithTranslation(for text: String) async {
        isLoading = true // Assuming you want to indicate loading state for translation as well.
        do {
            let translatedText = try await translationService.translate(text: text)
            DispatchQueue.main.async {
                // No longer needs Task, updates directly in the async context.
                self.translatedText = translatedText
                self.isLoading = false
            }
        } catch {
            DispatchQueue.main.async {
                self.error = error
                self.isLoading = false
            }
        }
    }
}

